:mod:`art.estimators.regression.scikitlearn`
============================================
.. automodule:: art.estimators.regression.scikitlearn

Base Class Scikit-learn
-----------------------
.. autoclass:: ScikitlearnRegressor
   :members:

Scikit-learn Decision Tree Regressor
------------------------------------
.. autoclass:: ScikitlearnDecisionTreeRegressor
   :members:
   :special-members: __init__
   :inherited-members:
